@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::ShareDir::Tarball::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dist::Zilla::Plugin::ShareDir::Tarball::VERSION = '0.2.0';
+  $Dist::Zilla::Plugin::ShareDir::Tarball::VERSION = '0.2.1';
 }
 # ABSTRACT: Bundle your shared dir into a tarball
 
@@ -52,7 +52,7 @@ Dist::Zilla::Plugin::ShareDir::Tarball - Bundle your shared dir into a tarball
 
 =head1 VERSION
 
-version 0.2.0
+version 0.2.1
 
 =head1 SYNOPSIS
 
@@ -99,6 +99,13 @@ with them.  If there is no such files, the process is simply skipped.
 L<Dist::Zilla::Plugin::ShareDir>, which you want to use in tandem with this
 module.
 
+L<File::ShareDir::Tarball> - transparently extract the tarball behind the
+scene so that the shared directory can be accessed just like it is in
+L<File::ShareDir>.
+
+L<Module::Build::CleanInstall> - A subclass of L<Module::Build> which
+deinstall the files from previous installations via their I<packlist>.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@babyl.dyndns.org>
